@@ -19,16 +19,18 @@ class AbstractNotebook:
   def set_box(self, box):
     self.box = box
 
-  def append_items(self, items):
-    self.pages = items
-    self.append_pages()
-
   def append_page(self, text, page):
+    try:
+      self.pages.append([text, self.append(text, page)])
+    except:
+      pass
+
+  def append(self, text, page):
     raise NotImplementedError('%s.append_page(text, page) must be implemented' % self.classname)
 
-  def append_pages(self):
+  def append_pages(self, items):
     self.pack_control()
-    for page in self.pages:
+    for page in items:
       self.append_page(page[0], page[1])
     self.set_active(0)
 
@@ -42,7 +44,7 @@ class AbstractNotebook:
     raise NotImplementedError('%s.get_area() must be implemented' % self.classname)
 
   def get_height(self):
-    if self.tabs_height<0:
+    if self.tabs_height < 0:
       return -1
     else:
       return self.tabs_height + self.pages_height
@@ -67,7 +69,7 @@ class NotebookMaemo4(AbstractNotebook):
     self.__notebook = gtk.Notebook()
     self.__notebook.set_scrollable(True)
 
-  def append_page(self, text, page):
+  def append(self, text, page):
     area = self.get_area()
     if type(page) != type(area):
       area.add_with_viewport(page)
@@ -76,6 +78,7 @@ class NotebookMaemo4(AbstractNotebook):
     self.__notebook.append_page(area, gtk.Label(text))
     self.tabs_height = self.__notebook.get_tab_label(area).size_request()[1]
     self.update_pages_height(page)
+    return area
 
   def pack_control(self):
     self.box.pack_start(self.__notebook)
@@ -96,16 +99,18 @@ class NotebookMaemo5(AbstractNotebook):
   def __init__(self, box=None, items=list()):
     AbstractNotebook.__init__(self, box, items)
     self.__toggle_control = advpowcommon.ui.ToggleControl.ToggleControlMaemo5()
+    self.__area = gtk.VBox()
 
-  def append_page(self, text, page):
+  def append(self, text, page):
 
     def page_toggle(widget, control, page):
       if widget.get_active():
-        pages = self.box.get_children()
-        for cpage in self.box:
-          cpage.hide_all()
-        control.get_box().show_all()
-        page.show_all()
+        for cpage in self.pages:
+          if cpage[1] == page:
+            page.show_all()
+          else:
+            cpage[1].hide_all()
+        #page.show_all()
 
     area = self.get_area()
     if type(page) != type(area):
@@ -113,12 +118,15 @@ class NotebookMaemo5(AbstractNotebook):
     else:
       area = page
     self.__toggle_control.add_button(text, page_toggle, area)
-    self.box.pack_start(area)
+    self.__area.pack_start(area, True)
     self.tabs_height = self.__toggle_control.get_box().size_request()[1]
     self.update_pages_height(page)
+    self.__area.set_size_request(-1, self.pages_height)
+    return area
 
   def pack_control(self):
     self.box.pack_start(self.__toggle_control.get_box(), False)
+    self.box.pack_start(self.__area, True)
 
   def set_active(self, ind):
     self.__toggle_control.set_active(ind)
@@ -126,4 +134,5 @@ class NotebookMaemo5(AbstractNotebook):
   def get_area(self):
     pa = hildon.PannableArea()
     pa.set_property('mov-mode', hildon.MOVEMENT_MODE_BOTH)
+#    pa.set_size_request_policy(hildon.SIZE_REQUEST_CHILDREN)
     return pa
